summary refs log tree commit diff
path: root/.circleci/merge_base_branch.sh
diff options
context:
space:
mode:
Diffstat (limited to '.circleci/merge_base_branch.sh')
-rwxr-xr-x.circleci/merge_base_branch.sh9
1 files changed, 5 insertions, 4 deletions
diff --git a/.circleci/merge_base_branch.sh b/.circleci/merge_base_branch.sh
index 4c19fa70d7..56895284ba 100755
--- a/.circleci/merge_base_branch.sh
+++ b/.circleci/merge_base_branch.sh
@@ -9,11 +9,12 @@ source $BASH_ENV
 
 if [[ -z "${CIRCLE_PR_NUMBER}" ]]
 then
-    echo "Can't figure out what the PR number is! Assuming merge target is develop."
+    echo "Can't figure out what the PR number is! Assuming merge target is dinsic."
 
-    # It probably hasn't had a PR opened yet. Since all PRs land on develop, we
-    # can probably assume it's based on it and will be merged into it.
-    GITBASE="develop"
+    # It probably hasn't had a PR opened yet. Since all PRs for dinsic land on
+    # dinsic, we can probably assume it's based on it and will be merged into
+    # it.
+    GITBASE="dinsic"
 else
     # Get the reference, using the GitHub API
     GITBASE=`wget -O- https://api.github.com/repos/matrix-org/synapse/pulls/${CIRCLE_PR_NUMBER} | jq -r '.base.ref'`